@@ -74,6 +74,7 @@ class gPodderEpisodes(BuilderWidget):
         for action in (self.action_update, \
                        self.action_rename, \
                        self.action_login, \
+                       self.action_website, \
                        self.action_unsubscribe, \
                        self.action_check_for_new_episodes, \
                        self.action_delete_episodes):
@@ -86,6 +87,11 @@ class gPodderEpisodes(BuilderWidget):
         self.pause_sub_button.connect('toggled', self.on_pause_subscription_button_toggled)
         appmenu.append(self.pause_sub_button)
 
+        self.keep_episodes_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.keep_episodes_button.set_label(_('Keep episodes'))
+        self.keep_episodes_button.connect('toggled', self.on_keep_episodes_button_toggled)
+        appmenu.append(self.keep_episodes_button)
+
         for filter in (self.item_view_episodes_all, \
                        self.item_view_episodes_undeleted, \
                        self.item_view_episodes_downloaded):
@@ -103,6 +109,18 @@ class gPodderEpisodes(BuilderWidget):
             self.channel.save()
             self.update_podcast_list_model(urls=[self.channel.url])
 
+    def on_keep_episodes_button_toggled(self, widget):
+        new_value = widget.get_active()
+        if new_value != self.channel.channel_is_locked:
+            self.channel.channel_is_locked = new_value
+            self.channel.update_channel_lock()
+
+        for episode in self.channel.get_all_episodes():
+            episode.mark(is_locked=self.channel.channel_is_locked)
+
+        self.update_podcast_list_model(urls=[self.channel.url])
+        self.episode_list_status_changed(self.channel.get_all_episodes())
+
     def on_rename_button_clicked(self, widget):
         if self.channel is None:
             return
@@ -221,14 +239,19 @@ class gPodderEpisodes(BuilderWidget):
 
         self.action_check_for_new_episodes.set_visible(all_episodes)
         self.action_delete_episodes.set_visible(True)
+        self.action_website.set_visible(True)
 
         if all_episodes:
             self.pause_sub_button.hide()
+            self.keep_episodes_button.hide()
         else:
             self.pause_sub_button.show()
+            self.keep_episodes_button.show()
 
         self.pause_sub_button.set_active(\
                 not self.channel.feed_update_enabled)
+        self.keep_episodes_button.set_active(\
+                self.channel.channel_is_locked)
 
         self.main_window.set_title(self.channel.title)
         self.main_window.show()
